package com.sooka.system.service;

import java.util.List;
import com.sooka.system.domain.TgjjZcxx;

/**
 * 政策信息Service接口
 * 
 * @author lei
 * @date 2021-11-16
 */
public interface ITgjjZcxxService 
{
    /**
     * 查询政策信息
     * 
     * @param ID 政策信息ID
     * @return 政策信息
     */
    public TgjjZcxx selectTgjjZcxxById(Long ID);

    /**
     * 查询政策信息列表
     * 
     * @param tgjjZcxx 政策信息
     * @return 政策信息集合
     */
    public List<TgjjZcxx> selectTgjjZcxxList(TgjjZcxx tgjjZcxx);

    /**
     * 新增政策信息
     * 
     * @param tgjjZcxx 政策信息
     * @return 结果
     */
    public int insertTgjjZcxx(TgjjZcxx tgjjZcxx);

    /**
     * 修改政策信息
     * 
     * @param tgjjZcxx 政策信息
     * @return 结果
     */
    public int updateTgjjZcxx(TgjjZcxx tgjjZcxx);

    /**
     * 批量删除政策信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTgjjZcxxByIds(String ids);

    /**
     * 删除政策信息信息
     * 
     * @param ID 政策信息ID
     * @return 结果
     */
    public int deleteTgjjZcxxById(Long ID);
}
